@@ -14,22 +14,24 @@
 #
 from __future__ import absolute_import
 
-from .audio_item import AudioItem
-from .audio_item_metadata import AudioItemMetadata
 from .audio_player_interface import AudioPlayerInterface
+from .playback_finished_request import PlaybackFinishedRequest
+from .stop_directive import StopDirective
+from .player_activity import PlayerActivity
+from .error import Error
+from .clear_queue_directive import ClearQueueDirective
+from .stream import Stream
 from .audio_player_state import AudioPlayerState
 from .clear_behavior import ClearBehavior
-from .clear_queue_directive import ClearQueueDirective
-from .current_playback_state import CurrentPlaybackState
-from .error import Error
-from .error_type import ErrorType
-from .play_behavior import PlayBehavior
-from .play_directive import PlayDirective
 from .playback_failed_request import PlaybackFailedRequest
-from .playback_finished_request import PlaybackFinishedRequest
-from .playback_nearly_finished_request import PlaybackNearlyFinishedRequest
-from .playback_started_request import PlaybackStartedRequest
 from .playback_stopped_request import PlaybackStoppedRequest
-from .player_activity import PlayerActivity
-from .stop_directive import StopDirective
-from .stream import Stream
+from .current_playback_state import CurrentPlaybackState
+from .caption_data import CaptionData
+from .play_directive import PlayDirective
+from .error_type import ErrorType
+from .audio_item import AudioItem
+from .caption_type import CaptionType
+from .audio_item_metadata import AudioItemMetadata
+from .play_behavior import PlayBehavior
+from .playback_started_request import PlaybackStartedRequest
+from .playback_nearly_finished_request import PlaybackNearlyFinishedRequest
