@@ -1,7 +1,7 @@
 # coding: utf-8
 
 #
-# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
 # except in compliance with the License. A copy of the License is located at
@@ -22,15 +22,17 @@ import typing
 from ask_sdk_model.services.base_service_client import BaseServiceClient
 from ask_sdk_model.services.api_configuration import ApiConfiguration
 from ask_sdk_model.services.service_client_response import ServiceClientResponse
+from ask_sdk_model.services.api_response import ApiResponse
+from ask_sdk_model.services.utils import user_agent_info
+
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Union
+    from typing import Dict, List, Union, Any
     from datetime import datetime
     from ask_sdk_model.services.ups.phone_number import PhoneNumber
     from ask_sdk_model.services.ups.distance_units import DistanceUnits
     import str
-    import bool
     from ask_sdk_model.services.ups.error import Error
     from ask_sdk_model.services.ups.temperature_unit import TemperatureUnit
 
@@ -38,24 +40,29 @@ if typing.TYPE_CHECKING:
 class UpsServiceClient(BaseServiceClient):
     """ServiceClient for calling the UpsService APIs.
 
-    :param api_configuration: Instance of :py:class:`ask_sdk_model.services.api_configuration.ApiConfiguration`
+    :param api_configuration: Instance of ApiConfiguration
     :type api_configuration: ask_sdk_model.services.api_configuration.ApiConfiguration
     """
-
-    def __init__(self, api_configuration):
-        # type: (ApiConfiguration) -> None
+    def __init__(self, api_configuration, custom_user_agent=None):
+        # type: (ApiConfiguration, str) -> None
         """
         :param api_configuration: Instance of :py:class:`ask_sdk_model.services.api_configuration.ApiConfiguration`
         :type api_configuration: ask_sdk_model.services.api_configuration.ApiConfiguration
+        :param custom_user_agent: Custom User Agent string provided by the developer.
+        :type custom_user_agent: str
         """
         super(UpsServiceClient, self).__init__(api_configuration)
+        self.user_agent = user_agent_info(sdk_version="1.0.0", custom_user_agent=custom_user_agent)
 
     def get_profile_email(self, **kwargs):
-        # type: () -> Union[str, Error]
+        # type: (**Any) -> Union[ApiResponse, str, Error]
         """
         Gets the email address of the customer associated with the current enablement. Requires customer consent for scopes: [alexa::profile:email:read] 
 
-        :rtype: Union[str, Error]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, str, Error]
         """
         operation_name = "get_profile_email"
         params = locals()
@@ -63,21 +70,29 @@ class UpsServiceClient(BaseServiceClient):
             params[key] = val
         del params['kwargs']
 
-        resource_path = '/v2/accounts/~current/settings/Profile.email'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/accounts/~current/settings/Profile.email'
+        resource_path = resource_path.replace('{format}', 'json')
 
-        query_params = []
+        path_params = {}  # type: Dict
 
-        header_params = []
+        query_params = []  # type: List
+
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="str", status_code=200, message="Successfully retrieved the requested information."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -85,7 +100,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -96,12 +111,19 @@ class UpsServiceClient(BaseServiceClient):
             response_definitions=error_definitions,
             response_type="str")
 
+        if full_response:
+            return api_response
+        return api_response.body
+
     def get_profile_given_name(self, **kwargs):
-        # type: () -> Union[str, Error]
+        # type: (**Any) -> Union[ApiResponse, str, Error]
         """
         Gets the given name (first name) of the customer associated with the current enablement. Requires customer consent for scopes: [alexa::profile:given_name:read] 
 
-        :rtype: Union[str, Error]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, str, Error]
         """
         operation_name = "get_profile_given_name"
         params = locals()
@@ -109,21 +131,29 @@ class UpsServiceClient(BaseServiceClient):
             params[key] = val
         del params['kwargs']
 
-        resource_path = '/v2/accounts/~current/settings/Profile.givenName'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/accounts/~current/settings/Profile.givenName'
+        resource_path = resource_path.replace('{format}', 'json')
 
-        query_params = []
+        path_params = {}  # type: Dict
 
-        header_params = []
+        query_params = []  # type: List
+
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="str", status_code=200, message="Successfully retrieved the requested information."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -131,7 +161,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -142,12 +172,19 @@ class UpsServiceClient(BaseServiceClient):
             response_definitions=error_definitions,
             response_type="str")
 
+        if full_response:
+            return api_response
+        return api_response.body
+
     def get_profile_mobile_number(self, **kwargs):
-        # type: () -> Union[PhoneNumber, Error]
+        # type: (**Any) -> Union[ApiResponse, PhoneNumber, Error]
         """
         Gets the mobile phone number of the customer associated with the current enablement. Requires customer consent for scopes: [alexa::profile:mobile_number:read] 
 
-        :rtype: Union[PhoneNumber, Error]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, PhoneNumber, Error]
         """
         operation_name = "get_profile_mobile_number"
         params = locals()
@@ -155,21 +192,29 @@ class UpsServiceClient(BaseServiceClient):
             params[key] = val
         del params['kwargs']
 
-        resource_path = '/v2/accounts/~current/settings/Profile.mobileNumber'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/accounts/~current/settings/Profile.mobileNumber'
+        resource_path = resource_path.replace('{format}', 'json')
 
-        query_params = []
+        path_params = {}  # type: Dict
 
-        header_params = []
+        query_params = []  # type: List
+
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.phone_number.PhoneNumber", status_code=200, message="Successfully retrieved the requested information."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -177,7 +222,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -188,12 +233,19 @@ class UpsServiceClient(BaseServiceClient):
             response_definitions=error_definitions,
             response_type="ask_sdk_model.services.ups.phone_number.PhoneNumber")
 
+        if full_response:
+            return api_response
+        return api_response.body
+
     def get_profile_name(self, **kwargs):
-        # type: () -> Union[str, Error]
+        # type: (**Any) -> Union[ApiResponse, str, Error]
         """
         Gets the full name of the customer associated with the current enablement. Requires customer consent for scopes: [alexa::profile:name:read] 
 
-        :rtype: Union[str, Error]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, str, Error]
         """
         operation_name = "get_profile_name"
         params = locals()
@@ -201,21 +253,29 @@ class UpsServiceClient(BaseServiceClient):
             params[key] = val
         del params['kwargs']
 
-        resource_path = '/v2/accounts/~current/settings/Profile.name'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/accounts/~current/settings/Profile.name'
+        resource_path = resource_path.replace('{format}', 'json')
 
-        query_params = []
+        path_params = {}  # type: Dict
 
-        header_params = []
+        query_params = []  # type: List
+
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="str", status_code=200, message="Successfully retrieved the requested information."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -223,7 +283,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -234,68 +294,21 @@ class UpsServiceClient(BaseServiceClient):
             response_definitions=error_definitions,
             response_type="str")
 
-    def get_geolocation_enablement_status(self, device_id, **kwargs):
-        # type: (str) -> Union[bool, Error]
-        """
-        Gets the geolocation status of the given device. Requires customer consent for scopes: [alexa::devices:all:geolocation:read] 
-
-        :param device_id: (required) The device Id
-        :type device_id: str
-        :rtype: Union[bool, Error]
-        """
-        operation_name = "get_geolocation_enablement_status"
-        params = locals()
-        for key, val in six.iteritems(params['kwargs']):
-            params[key] = val
-        del params['kwargs']
-        # verify the required parameter 'device_id' is set
-        if ('device_id' not in params) or (params['device_id'] is None):
-            raise ValueError(
-                "Missing the required parameter `device_id` when calling `" + operation_name + "`")
-
-        resource_path = '/v2/devices/{deviceId}/settings/Geolocation.enablementStatus'.replace('{format}', 'json')
-        path_params = {}
-        if 'device_id' in params:
-            path_params['deviceId'] = params['device_id']
-
-        query_params = []
-
-        header_params = []
-
-        body_params = None
-        header_params.append(('Content-type', 'application/json'))
-
-        # Authentication setting
-        authorization_value = "Bearer " + self._authorization_value
-        header_params.append(("Authorization", authorization_value))
-
-        error_definitions = []
-        error_definitions.append(ServiceClientResponse(response_type="bool", status_code=200, message="Successfully get the setting"))
-        error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
-        error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
-        error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=403, message="The authentication token does not have access to resource."))
-        error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
-        error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
-
-        return self.invoke(
-            method="GET",
-            endpoint=self._api_endpoint,
-            path=resource_path,
-            path_params=path_params,
-            query_params=query_params,
-            header_params=header_params,
-            body=body_params,
-            response_definitions=error_definitions,
-            response_type="bool")
+        if full_response:
+            return api_response
+        return api_response.body
 
     def get_system_distance_units(self, device_id, **kwargs):
-        # type: (str) -> Union[Error, DistanceUnits]
+        # type: (str, **Any) -> Union[ApiResponse, Error, DistanceUnits]
         """
         Gets the distance measurement unit of the device. Does not require explict customer consent. 
 
         :param device_id: (required) The device Id
         :type device_id: str
-        :rtype: Union[Error, DistanceUnits]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, Error, DistanceUnits]
         """
         operation_name = "get_system_distance_units"
         params = locals()
@@ -307,23 +320,31 @@ class UpsServiceClient(BaseServiceClient):
             raise ValueError(
                 "Missing the required parameter `device_id` when calling `" + operation_name + "`")
 
-        resource_path = '/v2/devices/{deviceId}/settings/System.distanceUnits'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/devices/{deviceId}/settings/System.distanceUnits'
+        resource_path = resource_path.replace('{format}', 'json')
+
+        path_params = {}  # type: Dict
         if 'device_id' in params:
             path_params['deviceId'] = params['device_id']
 
-        query_params = []
+        query_params = []  # type: List
 
-        header_params = []
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.distance_units.DistanceUnits", status_code=200, message="Successfully get the setting"))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -331,7 +352,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -342,14 +363,21 @@ class UpsServiceClient(BaseServiceClient):
             response_definitions=error_definitions,
             response_type="ask_sdk_model.services.ups.distance_units.DistanceUnits")
 
+        if full_response:
+            return api_response
+        return api_response.body
+
     def get_system_temperature_unit(self, device_id, **kwargs):
-        # type: (str) -> Union[TemperatureUnit, Error]
+        # type: (str, **Any) -> Union[ApiResponse, TemperatureUnit, Error]
         """
         Gets the temperature measurement units of the device. Does not require explict customer consent. 
 
         :param device_id: (required) The device Id
         :type device_id: str
-        :rtype: Union[TemperatureUnit, Error]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, TemperatureUnit, Error]
         """
         operation_name = "get_system_temperature_unit"
         params = locals()
@@ -361,23 +389,31 @@ class UpsServiceClient(BaseServiceClient):
             raise ValueError(
                 "Missing the required parameter `device_id` when calling `" + operation_name + "`")
 
-        resource_path = '/v2/devices/{deviceId}/settings/System.temperatureUnit'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/devices/{deviceId}/settings/System.temperatureUnit'
+        resource_path = resource_path.replace('{format}', 'json')
+
+        path_params = {}  # type: Dict
         if 'device_id' in params:
             path_params['deviceId'] = params['device_id']
 
-        query_params = []
+        query_params = []  # type: List
 
-        header_params = []
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.temperature_unit.TemperatureUnit", status_code=200, message="Successfully get the setting"))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -385,7 +421,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -396,14 +432,21 @@ class UpsServiceClient(BaseServiceClient):
             response_definitions=error_definitions,
             response_type="ask_sdk_model.services.ups.temperature_unit.TemperatureUnit")
 
+        if full_response:
+            return api_response
+        return api_response.body
+
     def get_system_time_zone(self, device_id, **kwargs):
-        # type: (str) -> Union[str, Error]
+        # type: (str, **Any) -> Union[ApiResponse, str, Error]
         """
         Gets the time zone of the device. Does not require explict customer consent. 
 
         :param device_id: (required) The device Id
         :type device_id: str
-        :rtype: Union[str, Error]
+        :param full_response: Boolean value to check if response should contain headers and status code information.
+            This value had to be passed through keyword arguments, by default the parameter value is set to False. 
+        :type full_response: boolean
+        :rtype: Union[ApiResponse, str, Error]
         """
         operation_name = "get_system_time_zone"
         params = locals()
@@ -415,23 +458,31 @@ class UpsServiceClient(BaseServiceClient):
             raise ValueError(
                 "Missing the required parameter `device_id` when calling `" + operation_name + "`")
 
-        resource_path = '/v2/devices/{deviceId}/settings/System.timeZone'.replace('{format}', 'json')
-        path_params = {}
+        resource_path = '/v2/devices/{deviceId}/settings/System.timeZone'
+        resource_path = resource_path.replace('{format}', 'json')
+
+        path_params = {}  # type: Dict
         if 'device_id' in params:
             path_params['deviceId'] = params['device_id']
 
-        query_params = []
+        query_params = []  # type: List
 
-        header_params = []
+        header_params = []  # type: List
 
         body_params = None
         header_params.append(('Content-type', 'application/json'))
+        header_params.append(('User-Agent', self.user_agent))
+
+        # Response Type
+        full_response = False
+        if 'full_response' in params:
+            full_response = params['full_response']
 
         # Authentication setting
         authorization_value = "Bearer " + self._authorization_value
         header_params.append(("Authorization", authorization_value))
 
-        error_definitions = []
+        error_definitions = []  # type: List
         error_definitions.append(ServiceClientResponse(response_type="str", status_code=200, message="Successfully get the setting"))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=204, message="The query did not return any results."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=401, message="The authentication token is malformed or invalid."))
@@ -439,7 +490,7 @@ class UpsServiceClient(BaseServiceClient):
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=429, message="The skill has been throttled due to an excessive number of requests."))
         error_definitions.append(ServiceClientResponse(response_type="ask_sdk_model.services.ups.error.Error", status_code=0, message="An unexpected error occurred."))
 
-        return self.invoke(
+        api_response = self.invoke(
             method="GET",
             endpoint=self._api_endpoint,
             path=resource_path,
@@ -449,3 +500,7 @@ class UpsServiceClient(BaseServiceClient):
             body=body_params,
             response_definitions=error_definitions,
             response_type="str")
+
+        if full_response:
+            return api_response
+        return api_response.body
